@@ -1,15 +1,13 @@
-#' @title SotkanetIndicators
-#' @description SotkanetIndicators retrieves Sotkanet data corresponding to a
-#' specified data identifier from 
-#' \url{http://www.sotkanet.fi/rest/1.1/indicators}
-#'
+#' @title Sotkanet Indicators
+#' @description Retrieve data for a specific data id.
+#  @details Data is fetched from 
+#'   \url{http://www.sotkanet.fi/rest/1.1/indicators}.
 #' @param id Dataset identifier
 #' @param type output format ("table" or "raw")
-#' @return sotkanet json query in selected output format
-#'
+#' @return json query in selected output format
 #' @export
 #' @references See citation("sotkanet") 
-#' @author Einari Happonen. Maintainer: Louhos/Opasnet \email{louhos@@googlegroups.com}
+#' @author Leo Lahti \email{leo.lahti@@iki.fi}
 #' @examples \dontrun{sotkanet.indicators <- SotkanetIndicators(type = "table")}
 #' @keywords utilities
 SotkanetIndicators <- function(id = NULL, type = "table")
@@ -21,7 +19,8 @@ SotkanetIndicators <- function(id = NULL, type = "table")
   if (!is.null(id))
     url <- paste(url, id, sep='/')
 
-  res <- sotkanet.json_query(url)
+  tmp <- try(res <- sotkanet.json_query(url))
+  if (is.null(tmp)) {warning("The URL may be temporarily unavailable. Try later.")}
 
   if (type == "table") {
     res <- SotkanetCollect(res, "indicator")
